# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import os
import unittest

import svn.core

import gvn.errors
import gvn.commit
import gvn.repository
from testing import testcommon
from testing.testcommon import RunSvn


class TestCommit(unittest.TestCase):

  def setUp(self):
    self.config = testcommon.GetConfig()
    self.repo_path = testcommon.NewTmpRepository()
    self.repo_url = testcommon.TmpRepositoryURL()

    self.pool = svn.core.Pool()
    self.repo = gvn.repository.Repository(testcommon.UnittestUser(),
                                          self.repo_url,
                                          self.config, self.pool)
    testcommon.GetAuthBaton(self.config, self.pool, self.repo)

  def testDelete(self):
    head = self.repo.GetHead()
    commit_info = gvn.commit.Drive(self.repo, {'svn:log': ''}, head, ['public'],
                                   (lambda *a: gvn.commit.Delete(head)),
                                   pool=self.pool)
    (revision,) = self.repo.GetRevisions(start=commit_info.revision)
    self.assertEquals([x.path for x in revision.paths], ['/public'])
    self.assertEquals(revision.paths[0].action, 'D')

  def testMkdir(self):
    head = self.repo.GetHead()
    commit_info = gvn.commit.Drive(self.repo, {'svn:log': ''}, head,
                                   ['public/projects/new1',
                                    'public/projects/new1/new2'],
                                   (lambda *a: gvn.commit.Mkdir(head)),
                                   pool=self.pool)
    (revision,) = self.repo.GetRevisions(start=commit_info.revision)
    self.assertEquals(sorted(x.path for x in revision.paths),
                      ['/public/projects/new1',
                       '/public/projects/new1/new2'])

  def testAbort(self):
    head = self.repo.GetHead()
    class exception(Exception):
      pass
    def action(path, pool):
      raise exception
    self.assertRaises(exception,
                      gvn.commit.Drive, self.repo, {'svn:log': ''}, head,
                      ['foo'], action, pool=self.pool)
    self.assertEquals(os.listdir(os.path.join(self.repo_path,
                                              'db/transactions')),
                      [])
